@@ -9,7 +9,7 @@ import re  # NOQA
 import builtins  # NOQA
 import datetime  # NOQA
 import decimal  # NOQA
-import ordered_set  # NOQA
+import orderly_set  # NOQA
 import collections  # NOQA
 try:
     import yaml
@@ -41,10 +41,21 @@ try:
 except ImportError:  # pragma: no cover.
     PydanticBaseModel = None
 
-from copy import deepcopy
+from copy import deepcopy, copy
 from functools import partial
 from collections.abc import Mapping
-from deepdiff.helper import (strings, get_type, TEXT_VIEW)
+from deepdiff.helper import (
+    strings,
+    get_type,
+    TEXT_VIEW,
+    np_float32,
+    np_float64,
+    np_int32,
+    np_int64,
+    np_ndarray,
+    Opcode,
+    SetOrdered,
+)
 from deepdiff.model import DeltaResult
 
 logger = logging.getLogger(__name__)
@@ -90,10 +101,14 @@ SAFE_TO_IMPORT = {
     'datetime.timedelta',
     'decimal.Decimal',
     'uuid.UUID',
-    'ordered_set.OrderedSet',
+    'orderly_set.sets.OrderedSet',
+    'orderly_set.sets.OrderlySet',
+    'orderly_set.sets.StableSetEq',
+    'deepdiff.helper.SetOrdered',
     'collections.namedtuple',
     'collections.OrderedDict',
     're.Pattern',
+    'deepdiff.helper.Opcode',
 }
 
 
@@ -118,7 +133,7 @@ TYPE_STR_TO_TYPE = {
     'time': datetime.time,
     'timedelta': datetime.timedelta,
     'Decimal': decimal.Decimal,
-    'OrderedSet': ordered_set.OrderedSet,
+    'SetOrdered': SetOrdered,
     'namedtuple': collections.namedtuple,
     'OrderedDict': collections.OrderedDict,
     'Pattern': re.Pattern,    
@@ -213,7 +228,7 @@ class SerializationMixin:
         view = view_override if view_override else self.view
         return dict(self._get_view_results(view))
 
-    def _to_delta_dict(self, directed=True, report_repetition_required=True):
+    def _to_delta_dict(self, directed=True, report_repetition_required=True, always_include_values=False):
         """
         Dump to a dictionary suitable for delta usage.
         Unlike to_dict, this is not dependent on the original view that the user chose to create the diff.
@@ -239,7 +254,29 @@ class SerializationMixin:
         if self.group_by is not None:
             raise ValueError(DELTA_ERROR_WHEN_GROUP_BY)
 
-        result = DeltaResult(tree_results=self.tree, ignore_order=self.ignore_order)
+        if directed and not always_include_values:
+            _iterable_opcodes = {}
+            for path, op_codes in self._iterable_opcodes.items():
+                _iterable_opcodes[path] = []
+                for op_code in op_codes:
+                    new_op_code = Opcode(
+                        tag=op_code.tag,
+                        t1_from_index=op_code.t1_from_index,
+                        t1_to_index=op_code.t1_to_index,
+                        t2_from_index=op_code.t2_from_index,
+                        t2_to_index=op_code.t2_to_index,
+                        new_values=op_code.new_values,
+                    )
+                    _iterable_opcodes[path].append(new_op_code)
+        else:
+            _iterable_opcodes = self._iterable_opcodes
+
+        result = DeltaResult(
+            tree_results=self.tree,
+            ignore_order=self.ignore_order,
+            always_include_values=always_include_values,
+            _iterable_opcodes=_iterable_opcodes,
+        )
         result.remove_empty_keys()
         if report_repetition_required and self.ignore_order and not self.report_repetition:
             raise ValueError(DELTA_IGNORE_ORDER_NEEDS_REPETITION_REPORT)
@@ -254,6 +291,9 @@ class SerializationMixin:
             # and will be omitted when counting distance. (Look inside the distance module.)
             result['_numpy_paths'] = self._numpy_paths
 
+        if self.iterable_compare_func:
+            result['_iterable_compare_func_was_used'] = True
+
         return deepcopy(dict(result))
 
     def pretty(self):
@@ -532,13 +572,28 @@ def _serialize_decimal(value):
         return float(value)
 
 
+def _serialize_tuple(value):
+    if hasattr(value, '_asdict'):  # namedtuple
+        return value._asdict()
+    return value
+
+
 JSON_CONVERTOR = {
     decimal.Decimal: _serialize_decimal,
-    ordered_set.OrderedSet: list,
+    SetOrdered: list,
+    orderly_set.StableSetEq: list,
+    set: list,
     type: lambda x: x.__name__,
     bytes: lambda x: x.decode('utf-8'),
     datetime.datetime: lambda x: x.isoformat(),
     uuid.UUID: lambda x: str(x),
+    np_float32: float,
+    np_float64: float,
+    np_int32: int,
+    np_int64: int,
+    np_ndarray: lambda x: x.tolist(),
+    tuple: _serialize_tuple,
+    Mapping: dict,
 }
 
 if PydanticBaseModel:
@@ -556,6 +611,9 @@ def json_convertor_default(default_mapping=None):
         for original_type, convert_to in _convertor_mapping.items():
             if isinstance(obj, original_type):
                 return convert_to(obj)
+        # This is to handle reverse() which creates a generator of type list_reverseiterator
+        if obj.__class__.__name__ == 'list_reverseiterator':
+            return list(copy(obj))
         raise TypeError('We do not know how to convert {} of type {} for json serialization. Please pass the default_mapping parameter with proper mapping of the object to a basic python type.'.format(obj, type(obj)))
 
     return _convertor
